Index: trunk/psLib/test/astronomy/tst_psTime_01.c
===================================================================
--- trunk/psLib/test/astronomy/tst_psTime_01.c	(revision 3710)
+++ trunk/psLib/test/astronomy/tst_psTime_01.c	(revision 3712)
@@ -23,6 +23,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.24 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2005-04-19 00:17:06 $
+ *  @version $Revision: 1.25 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2005-04-19 02:13:53 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -44,5 +44,5 @@
     testTime = (psTime*)psAlloc(sizeof(psTime));
     testTime->sec = 1090434144;
-    testTime->usec = 272044;
+    testTime->nsec = 272044000;
     testTime->type = PS_TIME_TAI;
 
@@ -57,7 +57,7 @@
     // Test B - Print test time
     printPositiveTestHeader(stdout,"psTime", "Print test time");
-    printf("Test time: Seconds = %lld Microseconds = %u\n",
+    printf("Test time: Seconds = %lld Nanoseconds = %u\n",
            (long long int)testTime->sec,
-           testTime->usec);
+           testTime->nsec);
     printFooter(stdout, "psTime", "Print test time", true);
 
@@ -79,7 +79,7 @@
     psTime *timeD = NULL;
     timeD = psTimeFromISO(isoString);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeD->sec,
-           timeD->usec);
+           timeD->nsec);
     psFree(isoString);
     psFree(timeD);
@@ -92,11 +92,11 @@
     timeE = (psTime*)psAlloc(sizeof(psTime));
     timeE->sec = 1090434144;
-    timeE->usec = 272044;
+    timeE->nsec = 272044000;
     timeE->type = PS_TIME_TAI;
     timeE = psTimeConvert(timeE, PS_TIME_UTC);
     psFree(timeE);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeE->sec,
-           timeE->usec);
+           timeE->nsec);
     printFooter(stdout, "psTime", "Convert psTime time to UTC time", true);
 
@@ -107,11 +107,11 @@
     timeF = (psTime*)psAlloc(sizeof(psTime));
     timeF->sec = 1090434112;
-    timeF->usec = 272044;
+    timeF->nsec = 272044000;
     timeF->type = PS_TIME_UTC;
     timeF = psTimeConvert(timeF, PS_TIME_TAI);
     psFree(timeF);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeF->sec,
-           timeF->usec);
+           timeF->nsec);
     printFooter(stdout, "psTime", "Convert UTC time to psTime", true);
 
@@ -129,7 +129,7 @@
     psTime *timeH = NULL;
     timeH = psTimeFromMJD(mjdTime);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeH->sec,
-           timeH->usec);
+           timeH->nsec);
     psFree(timeH);
     printFooter(stdout, "psTime", "Convert MJD time to psTime", true);
@@ -148,7 +148,7 @@
     psTime *timeJ = NULL;
     timeJ = psTimeFromJD(jdTime);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeJ->sec,
-           timeJ->usec);
+           timeJ->nsec);
     psFree(timeJ);
     printFooter(stdout, "psTime", "Convert JD time to psTime", true);
@@ -169,7 +169,7 @@
     psTime *timeL = NULL;
     timeL = psTimeFromTimeval(&timevalTime);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeL->sec,
-           timeL->usec);
+           timeL->nsec);
     psFree(timeL);
     printFooter(stdout, "psTime", "Convert timeval time to psTime", true);
@@ -194,7 +194,7 @@
     psTime *timeN = NULL;
     timeN = psTimeFromTM(tmTime);
-    printf("psTime: Seconds = %lld Microseconds = %u\n",
+    printf("psTime: Seconds = %lld Nanoseconds = %u\n",
            (long long int)timeN->sec,
-           timeN->usec);
+           timeN->nsec);
     psFree(timeN);
     psFree(tmTime);
Index: trunk/psLib/test/astronomy/verified/tst_psTime_01.stdout
===================================================================
--- trunk/psLib/test/astronomy/verified/tst_psTime_01.stdout	(revision 3710)
+++ trunk/psLib/test/astronomy/verified/tst_psTime_01.stdout	(revision 3712)
@@ -14,5 +14,5 @@
 \**********************************************************************************/
 
-Test time: Seconds = 1090434144 Microseconds = 272044
+Test time: Seconds = 1090434144 Nanoseconds = 272044000
 
 ---> TESTPOINT PASSED (psTime{Print test time} | tst_psTime_01.c)
@@ -34,5 +34,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 272000
+psTime: Seconds = 1090434144 Nanoseconds = 272000000
 
 ---> TESTPOINT PASSED (psTime{Convert ISO time to psTime} | tst_psTime_01.c)
@@ -44,5 +44,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434112 Microseconds = 272044
+psTime: Seconds = 1090434112 Nanoseconds = 272044000
 
 ---> TESTPOINT PASSED (psTime{Convert psTime time to UTC time} | tst_psTime_01.c)
@@ -54,5 +54,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 272044
+psTime: Seconds = 1090434144 Nanoseconds = 272044000
 
 ---> TESTPOINT PASSED (psTime{Convert UTC time to psTime} | tst_psTime_01.c)
@@ -74,5 +74,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 272043
+psTime: Seconds = 1090434144 Nanoseconds = 272043704
 
 ---> TESTPOINT PASSED (psTime{Convert MJD time to psTime} | tst_psTime_01.c)
@@ -94,5 +94,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 272048
+psTime: Seconds = 1090434144 Nanoseconds = 272048711
 
 ---> TESTPOINT PASSED (psTime{Convert JD time to psTime} | tst_psTime_01.c)
@@ -114,5 +114,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 272044
+psTime: Seconds = 1090434144 Nanoseconds = 272044000
 
 ---> TESTPOINT PASSED (psTime{Convert timeval time to psTime} | tst_psTime_01.c)
@@ -140,5 +140,5 @@
 \**********************************************************************************/
 
-psTime: Seconds = 1090434144 Microseconds = 0
+psTime: Seconds = 1090434144 Nanoseconds = 0
 
 ---> TESTPOINT PASSED (psTime{Convert tm time to psTime} | tst_psTime_01.c)
Index: trunk/psLib/test/astronomy/verified/tst_psTime_03.stdout
===================================================================
--- trunk/psLib/test/astronomy/verified/tst_psTime_03.stdout	(revision 3710)
+++ trunk/psLib/test/astronomy/verified/tst_psTime_03.stdout	(revision 3712)
@@ -28,10 +28,10 @@
 /***************************** TESTPOINT ******************************************\
 *             TestFile: tst_psTime_03.c                                            *
-*            TestPoint: psTime{Test D - Subtact two times with underflow in microseconds} *
+*            TestPoint: psTime{Test D - Subtact two times with underflow in nanoseconds} *
 *             TestType: Positive                                                   *
 \**********************************************************************************/
 
 
----> TESTPOINT PASSED (psTime{Test D - Subtact two times with underflow in microseconds} | tst_psTime_03.c)
+---> TESTPOINT PASSED (psTime{Test D - Subtact two times with underflow in nanoseconds} | tst_psTime_03.c)
 
 /***************************** TESTPOINT ******************************************\

Index: trunk/psLib/test/astronomy/tst_psTime_03.c
===================================================================
--- trunk/psLib/test/astronomy/tst_psTime_03.c	(revision 3710)
+++ trunk/psLib/test/astronomy/tst_psTime_03.c	(revision 3712)
@@ -19,6 +19,6 @@
  *  @author  Ross Harman, MHPCC
  *
- *  @version $Revision: 1.15 $  $Name: not supported by cvs2svn $
- *  @date  $Date: 2005-04-18 23:30:54 $
+ *  @version $Revision: 1.16 $  $Name: not supported by cvs2svn $
+ *  @date  $Date: 2005-04-19 02:13:53 $
  *
  *  Copyright 2004-2005 Maui High Performance Computing Center, University of Hawaii
@@ -30,5 +30,5 @@
 
 #define PRINT_TIME(TEXT,TIME) \
-printf("%s Seconds = %lld Microseconds = %u\n", TEXT, (long long int)TIME->sec, TIME->usec);
+printf("%s Seconds = %lld Nanoseconds = %u\n", TEXT, (long long int)TIME->sec, TIME->nsec);
 
 psS32 main(psS32 argc, char* argv[])
@@ -44,13 +44,13 @@
     time1a = psTimeAlloc(PS_TIME_TAI);
     time1a->sec  = 1;
-    time1a->usec = 111111;
+    time1a->nsec = 111111000;
     timeOut1 = psTimeMath(time1a, time1b);
-    if(timeOut1->sec!=2 && timeOut1->usec!=222222) {
-        printf("ERROR: Incorrect time, %lld:%u. Expected 2:222222\n",(long long int)timeOut1->sec, timeOut1->usec);
+    if(timeOut1->sec!=2 && timeOut1->nsec!=222222000) {
+        printf("ERROR: Incorrect time, %lld:%u. Expected 2:222222000\n",(long long int)timeOut1->sec, timeOut1->nsec);
     }
     printFooter(stdout, "psTime", "Test A - Add two times", true);
 
 
     // Test B - Add two times with overflow in microseconds
     printPositiveTestHeader(stdout, "psTime", "Test B - Add two times with overflow in microseconds");
     psTime *time2a = NULL;
@@ -59,8 +59,8 @@
     time2a = psTimeAlloc(PS_TIME_TAI);
     time2a->sec  = 6;
-    time2a->usec = 600001;
+    time2a->nsec = 600001000;
     timeOut2 = psTimeMath(time2a, time2b);
-    if(timeOut2->sec!=12 && timeOut2->usec!=100002) {
-        printf("ERROR: Incorrect time, %lld:%u. Expected 12:100002\n",(long long int)timeOut2->sec, timeOut2->usec);
+    if(timeOut2->sec!=12 && timeOut2->nsec!=100002000) {
+        printf("ERROR: Incorrect time, %lld:%u. Expected 12:100002000\n",(long long int)timeOut2->sec, timeOut2->nsec);
     }
     printFooter(stdout, "psTime", "Test B - Add two times with overflow in microseconds", true);
@@ -74,14 +74,14 @@
     time3a = psTimeAlloc(PS_TIME_TAI);
     time3a->sec  = 3;
-    time3a->usec = 333333;
+    time3a->nsec = 333333000;
     timeOut3 = psTimeMath(time3a, time3b);
-    if(timeOut3->sec!=2 && timeOut3->usec!=222222) {
-        printf("ERROR: Incorrect time, %lld:%u. Expected 2:222222\n",(long long int)timeOut3->sec, timeOut3->usec);
+    if(timeOut3->sec!=2 && timeOut3->nsec!=222222000) {
+        printf("ERROR: Incorrect time, %lld:%u. Expected 2:222222000\n",(long long int)timeOut3->sec, timeOut3->nsec);
     }
     printFooter(stdout, "psTime", "Test C - Subtract two times", true);
 
 
-    // Test D - Subtact two times with underflow in microseconds
-    printPositiveTestHeader(stdout, "psTime", "Test D - Subtact two times with underflow in microseconds");
+    // Test D - Subtact two times with underflow in nanoseconds
+    printPositiveTestHeader(stdout, "psTime", "Test D - Subtact two times with underflow in nanoseconds");
     psTime *time4a = NULL;
     psF64 time4b = -2.000003;
@@ -89,10 +89,10 @@
     time4a = psTimeAlloc(PS_TIME_TAI);
     time4a->sec  = 5;
-    time4a->usec = 1;
+    time4a->nsec = 1000;
     timeOut4 = psTimeMath(time4a, time4b);
-    if(timeOut4->sec!=2 && timeOut4->usec!=999997) {
-        printf("ERROR: Incorrect time, %lld:%u. Expected 2:999997\n",(long long int)timeOut4->sec, timeOut4->usec);
-    }
-    printFooter(stdout, "psTime", "Test D - Subtact two times with underflow in microseconds", true);
+    if(timeOut4->sec!=2 && timeOut4->nsec!=999997000) {
+        printf("ERROR: Incorrect time, %lld:%u. Expected 2:999997000\n",(long long int)timeOut4->sec, timeOut4->nsec);
+    }
+    printFooter(stdout, "psTime", "Test D - Subtact two times with underflow in nanoseconds", true);
 
 
@@ -105,7 +105,7 @@
     time5b = psTimeAlloc(PS_TIME_TAI);
     time5a->sec  = 8;
-    time5a->usec = 8;
+    time5a->nsec = 8000;
     time5b->sec  = 7;
-    time5b->usec = 7;
+    time5b->nsec = 7000;
     timeOut5 = psTimeDelta(time5a, time5b);
     if(fabs(timeOut5-1.000001) > FLT_EPSILON) {
@@ -123,7 +123,7 @@
     time6b = psTimeAlloc(PS_TIME_TAI);
     time6a->sec  = 8;
-    time6a->usec = 1;
+    time6a->nsec = 1000;
     time6b->sec  = 7;
-    time6b->usec = 7;
+    time6b->nsec = 7000;
     timeOut6 = psTimeDelta(time6a, time6b);
     if(fabs(timeOut6-0.999994) > FLT_EPSILON) {
@@ -140,7 +140,7 @@
     time20b = psTimeAlloc(PS_TIME_UTC);
     time20a->sec = 1090434113;
-    time20a->usec = 272044;
+    time20a->nsec = 272044000;
     time20b->sec = 1090434112;
-    time20b->usec = 272044;
+    time20b->nsec = 272044000;
     timeOut20 = psTimeDelta(time20a, time20b);
     if(fabs(timeOut20-1.000000000) > FLT_EPSILON) {
@@ -44,13 +44,13 @@
 
 
-    // Test B - Add two times with overflow in microseconds
+    // Test B - Add two times with overflow in nanoseconds
     printPositiveTestHeader(stdout, "psTime", "Test B - Add two times with overflow in microseconds");
     psTime *time2a = NULL;